# CHANGELOG

## 0.7.0

- unless -> when [#35](https://github.com/opendp/dp-wizard-templates/pull/35)

## 0.6.0

- ignore spurious warning [#33](https://github.com/opendp/dp-wizard-templates/pull/33)
- `unless` kwarg [#32](https://github.com/opendp/dp-wizard-templates/pull/32)
- Warn if lower case kwargs [#31](https://github.com/opendp/dp-wizard-templates/pull/31)
- `fill_argument_expressions` and `fill_argument_values` [#27](https://github.com/opendp/dp-wizard-templates/pull/27)

## 0.5.0

- fill_attribute_slots() [#24](https://github.com/opendp/dp-wizard-templates/pull/24)
- Add isort and check precommits in CI [#23](https://github.com/opendp/dp-wizard-templates/pull/23)

## 0.4.0

- Safer template filling, and option to ignore slots [#20](https://github.com/opendp/dp-wizard-templates/pull/20)
- Check for `root` kwarg, and fix test coverage [#19](https://github.com/opendp/dp-wizard-templates/pull/19)

## 0.3.0

- Show all errors, and support comment blocks [#12](https://github.com/opendp/dp-wizard-templates/pull/12)

## 0.2.0

- Link to ghpages [#7](https://github.com/opendp/dp-wizard-templates/pull/7)
- Add black, and a generated index.html [#6](https://github.com/opendp/dp-wizard-templates/pull/6)

## 0.1.0

Initial release